==> gsynaptics_0.9.12.orig.tar.gz: gsynaptics-0.9.12/src/gsynaptics-conf.h <==
/*
 *  Copyright (C) 2005 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __G_SYNAPTICS_CONF_H__
#define __G_SYNAPTICS_CONF_H__

#include <glib.h>

G_BEGIN_DECLS

#define DIRNAME		 	"/desktop/gnome/peripherals/touchpad"
#define SENSITIVITY_KEY 	"/desktop/gnome/peripherals/touchpad/sensitivity"
#define OFF_KEY 		"/desktop/gnome/peripherals/touchpad/off"
#define MAXTAPTIME_KEY 		"/desktop/gnome/peripherals/touchpad/max_tap_time"
#define HORIZSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/horiz_scroll_delta"
#define VERTSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/vert_scroll_delta"
#define EDGEMOTIONUSEALWAYS_KEY "/desktop/gnome/peripherals/touchpad/edge_motion_use_always"
#define COASTENABLE_KEY 	"/desktop/gnome/peripherals/touchpad/coast_enable"
#define CIRCULARSCROLLING_KEY 	"/desktop/gnome/peripherals/touchpad/circular_scrolling"
#define CIRCSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/circ_scroll_delta"
#define CIRCSCROLLTRIGGER_KEY 	"/desktop/gnome/peripherals/touchpad/circ_scroll_trigger"
#define FASTTAPS_KEY		"/desktop/gnome/peripherals/touchpad/fast_taps"
#define BUTTONFORTAP_KEY 	"/desktop/gnome/peripherals/touchpad/button_for_tap"
#define ABSCOORDX_KEY 		"/desktop/gnome/peripherals/touchpad/abs_coord_x"
#define ABSCOORDY_KEY 		"/desktop/gnome/peripherals/touchpad/abs_coord_y"

G_END_DECLS

#endif /* __G_SYNAPTICS_CONF_H__ */

==> gsynaptics_0.9.16.orig.tar.gz: gsynaptics-0.9.16/src/gsynaptics-conf.h <==
/*
 *  Copyright (C) 2005 Hiroyuki Ikezoe
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __G_SYNAPTICS_CONF_H__
#define __G_SYNAPTICS_CONF_H__

#include <glib.h>

G_BEGIN_DECLS

#define DIRNAME		 	"/desktop/gnome/peripherals/touchpad"
#define SENSITIVITY_KEY 	"/desktop/gnome/peripherals/touchpad/sensitivity"
#define OFF_KEY 		"/desktop/gnome/peripherals/touchpad/off"
#define MAXTAPTIME_KEY 		"/desktop/gnome/peripherals/touchpad/max_tap_time"
#define HORIZSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/horiz_scroll_delta"
#define VERTSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/vert_scroll_delta"
#define EDGEMOTIONUSEALWAYS_KEY "/desktop/gnome/peripherals/touchpad/edge_motion_use_always"
#define COASTENABLE_KEY 	"/desktop/gnome/peripherals/touchpad/coast_enable"
#define CIRCULARSCROLLING_KEY 	"/desktop/gnome/peripherals/touchpad/circular_scrolling"
#define CIRCSCROLLDELTA_KEY 	"/desktop/gnome/peripherals/touchpad/circ_scroll_delta"
#define CIRCSCROLLTRIGGER_KEY 	"/desktop/gnome/peripherals/touchpad/circ_scroll_trigger"
#define FASTTAPS_KEY		"/desktop/gnome/peripherals/touchpad/fast_taps"
#define BUTTONFORTAP_KEY 	"/desktop/gnome/peripherals/touchpad/button_for_tap"
#define ABSCOORDX_KEY 		"/desktop/gnome/peripherals/touchpad/abs_coord_x"
#define ABSCOORDY_KEY 		"/desktop/gnome/peripherals/touchpad/abs_coord_y"

#define MINSPEED_KEY 		"/desktop/gnome/peripherals/touchpad/min_speed"
#define MAXSPEED_KEY 		"/desktop/gnome/peripherals/touchpad/max_speed"
#define ACCELFACTOR_KEY 	"/desktop/gnome/peripherals/touchpad/accel_factor"


G_END_DECLS

#endif /* __G_SYNAPTICS_CONF_H__ */
